Various renames following the name change from "Runtime APEX" to "ART APEX".

In particular ANDROID_RUNTIME_ROOT is now ANDROID_ART_ROOT.

Test: Build & boot
Test: art/tools/run-gtests.sh in chroot
Test: art/test/testrunner/testrunner.py --target --64 in chroot
Test: art/tools/run-libcore-tests.sh --mode=device --variant=X64 in chroot
Test: art/tools/run-jdwp-tests.sh --mode=device --variant=X64 in chroot
Test: m test-art-host-gtest
Test: art/test/testrunner/testrunner.py --host --64
Test: art/tools/run-jdwp-tests.sh --mode=host
Bug: 135753770
Change-Id: Ia74da964e54cf396d66e9e12ea56da4e9483662a
diff --git a/build/apex/art_apex_test.py b/build/apex/art_apex_test.py
index 6d29fc9..ee372f4 100755
--- a/build/apex/art_apex_test.py
+++ b/build/apex/art_apex_test.py
@@ -29,10 +29,10 @@
 
 # Architectures supported by APEX packages.
 archs = ["arm", "arm64", "x86", "x86_64"]
-# Directory containing ART tests within a Runtime APEX (if the package includes
+# Directory containing ART tests within an ART APEX (if the package includes
 # any). ART test executables are installed in `bin/art/<arch>`. Segregating
 # tests by architecture is useful on devices supporting more than one
 # architecture, as it permits testing all of them using a single Runtime APEX
 # package.
 art_test_dir = 'bin/art'
 
@@ -1223,7 +1223,7 @@
 
 
 if __name__ == "__main__":
-  parser = argparse.ArgumentParser(description='Check integrity of a Runtime APEX.')
+  parser = argparse.ArgumentParser(description='Check integrity of an ART APEX.')
 
   parser.add_argument('apex', help='APEX file input')
@@ -29,10 +29,10 @@
 # any). ART test executables are installed in `bin/art/<arch>`. Segregating
 # tests by architecture is useful on devices supporting more than one
-# architecture, as it permits testing all of them using a single Runtime APEX
+# architecture, as it permits testing all of them using a single ART APEX
 # package.
 art_test_dir = 'bin/art'